@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 from collections import Counter
 
@@ -5,14 +7,14 @@ import lxml.html
 
 from . import constants, t
 
-messages: t.Set[str]
+messages: t.Set[t.Union[str, t.Tuple[str, str]]]
 messages = set()
 
 messageCounts: t.Dict[str, int]
 messageCounts = Counter()
 
 
-def p(msg, sep=None, end=None):
+def p(msg: t.Union[str, t.Tuple[str, str]], sep: t.Optional[str] = None, end: t.Optional[str] = None) -> None:
     if constants.quiet == float("infinity"):
         return
     if isinstance(msg, tuple):
@@ -37,74 +39,75 @@ def p(msg, sep=None, end=None):
             print(msg.encode("ascii", "xmlcharrefreplace"), sep=sep, end=end)
 
 
-def die(msg, el=None, lineNum=None):
+def die(msg: str, el: t.Optional[t.ElementT] = None, lineNum: t.Optional[str] = None) -> None:
     if lineNum is None and el is not None and el.get("line-number"):
         lineNum = el.get("line-number")
-    msg = formatMessage("fatal", msg, lineNum=lineNum)
-    if msg not in messages:
+    formattedMsg = formatMessage("fatal", msg, lineNum=lineNum)
+    if formattedMsg not in messages:
         messageCounts["fatal"] += 1
-        messages.add(msg)
+        messages.add(formattedMsg)
         if constants.quiet < 3:
-            p(msg)
+            p(formattedMsg)
     if constants.errorLevelAt("fatal"):
         errorAndExit()
 
 
-def linkerror(msg, el=None, lineNum=None):
+def linkerror(msg: str, el: t.Optional[t.ElementT] = None, lineNum: t.Optional[str] = None) -> None:
     if lineNum is None and el is not None and el.get("line-number"):
         lineNum = el.get("line-number")
     suffix = ""
     if el is not None:
         if el.get("bs-autolink-syntax"):
-            suffix = "\n" + el.get("bs-autolink-syntax")
+            suffix = "\n" + t.cast(str, el.get("bs-autolink-syntax"))
         else:
             suffix = "\n" + lxml.html.tostring(el, with_tail=False, encoding="unicode")
-    msg = formatMessage("link", msg + suffix, lineNum=lineNum)
-    if msg not in messages:
+    formattedMsg = formatMessage("link", msg + suffix, lineNum=lineNum)
+    if formattedMsg not in messages:
         messageCounts["linkerror"] += 1
-        messages.add(msg)
+        messages.add(formattedMsg)
         if constants.quiet < 2:
-            p(msg)
+            p(formattedMsg)
     if constants.errorLevelAt("link-error"):
         errorAndExit()
 
 
-def warn(msg, el=None, lineNum=None):
+def warn(msg: str, el: t.Optional[t.ElementT] = None, lineNum: t.Optional[str] = None) -> None:
     if lineNum is None and el is not None and el.get("line-number"):
         lineNum = el.get("line-number")
-    msg = formatMessage("warning", msg, lineNum=lineNum)
-    if msg not in messages:
+    formattedMsg = formatMessage("warning", msg, lineNum=lineNum)
+    if formattedMsg not in messages:
         messageCounts["warning"] += 1
-        messages.add(msg)
+        messages.add(formattedMsg)
         if constants.quiet < 1:
-            p(msg)
+            p(formattedMsg)
     if constants.errorLevelAt("warning"):
         errorAndExit()
 
 
-def say(msg):
+def say(msg: str) -> None:
     if constants.quiet < 1:
         p(formatMessage("message", msg))
 
 
-def success(msg):
+def success(msg: str) -> None:
     if constants.quiet < 4:
         p(formatMessage("success", msg))
 
 
-def failure(msg):
+def failure(msg: str) -> None:
     if constants.quiet < 4:
         p(formatMessage("failure", msg))
 
 
-def resetSeenMessages():
+def resetSeenMessages() -> None:
     global messages
     messages = set()
     global messageCounts
     messageCounts = Counter()
+    return
 
 
-def printColor(text, color="white", *styles):
+def printColor(text: str, color: str = "white", *styles: str) -> str:
     if constants.printMode == "console":
         colorsConverter = {
             "black": 30,
@@ -143,7 +146,7 @@ def printColor(text, color="white", *styles):
     return text
 
 
-def formatMessage(type, text, lineNum=None):
+def formatMessage(type: str, text: str, lineNum: t.Optional[str] = None) -> t.Union[str, t.Tuple[str, str]]:
     if constants.printMode == "markup":
         text = text.replace("<", "&lt;")
         if type == "fatal":
@@ -158,33 +161,32 @@ def formatMessage(type, text, lineNum=None):
             return f"<final-success>{text}</final-success>"
         if type == "failure":
             return f"<final-failure>{text}</final-failure>"
-    else:
-        if type == "message":
-            return text
-        if type == "success":
-            return (
-                printColor(" ✔ ", "green", "invert") + " " + text,
-                printColor("YAY", "green", "invert") + " " + text,
-            )
-        if type == "failure":
-            return (
-                printColor(" ✘ ", "red", "invert") + " " + text,
-                printColor("ERR", "red", "invert") + " " + text,
-            )
-        if type == "fatal":
-            headingText = "FATAL ERROR"
-            color = "red"
-        elif type == "link":
-            headingText = "LINK ERROR"
-            color = "yellow"
-        elif type == "warning":
-            headingText = "WARNING"
-            color = "light cyan"
-        if lineNum is not None:
-            headingText = f"LINE {lineNum}"
-        return printColor(headingText + ":", color, "bold") + " " + text
+    if type == "message":
+        return text
+    if type == "success":
+        return (
+            printColor(" ✔ ", "green", "invert") + " " + text,
+            printColor("YAY", "green", "invert") + " " + text,
+        )
+    if type == "failure":
+        return (
+            printColor(" ✘ ", "red", "invert") + " " + text,
+            printColor("ERR", "red", "invert") + " " + text,
+        )
+    if type == "fatal":
+        headingText = "FATAL ERROR"
+        color = "red"
+    elif type == "link":
+        headingText = "LINK ERROR"
+        color = "yellow"
+    elif type == "warning":
+        headingText = "WARNING"
+        color = "light cyan"
+    if lineNum is not None:
+        headingText = f"LINE {lineNum}"
+    return printColor(headingText + ":", color, "bold") + " " + text
 
 
-def errorAndExit():
+def errorAndExit() -> None:
     failure("Did not generate, due to fatal errors")
     sys.exit(2)
